DoctorView class

The core Doctor UI component.

Constructors

DoctorView({required String pluginName, required List<DoctorSection> sections, required int errors, required int warnings, String? errorMessage, VoidCallback? onExit, Key? key})
const

Properties

errorMessage String?
final
errors int
final
hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
onExit → VoidCallback?
final
pluginName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<DoctorSection>
final
warnings int
final

Methods

createElement() → StatefulElement
inherited
createState() → State<DoctorView>
Creates the mutable state for this component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited