DoctorViewResult class
Constructors
-
DoctorViewResult({required String pluginName, required List<
DoctorSection> sections, required int errors, required int warnings}) -
const
Properties
- errors → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pluginName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
DoctorSection> -
final
- warnings → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited