IncrementalGenerationCache class
Constructors
- IncrementalGenerationCache(String projectRoot)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- manifestFile → File
-
no setter
- projectRoot → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plan(
{required List< File> specs, required List<String> outputPathsForSpec(File spec)}) → IncrementalGenerationPlan -
toString(
) → String -
A string representation of this object.
inherited
-
write(
{required List< File> specs, required List<String> outputPathsForSpec(File spec)}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
contentHash(
File file) → String
Constants
- manifestRelativePath → const String