InitStepRow class

Constructors

InitStepRow(InitStep step, {Key? key})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step InitStep
final

Methods

build(BuildContext context) → Component
Describes the part of the user interface represented by this component.
createElement() → StatelessElement
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited