InitView class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
finalinherited
- onExit → VoidCallback?
-
final
- org → String
-
final
-
platforms
→ List<
String> -
Platforms to scaffold. Valid values: android, ios, macos, windows, linux.
final
- pluginName → String
-
final
- result → InitResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< InitView> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited