NitrogenInitApp class
Constructors
- NitrogenInitApp({required InitResult result, String? initialOrg, VoidCallback? onExit, Key? key})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialOrg → String?
-
final
- key → Key?
-
finalinherited
- onExit → VoidCallback?
-
final
- result → InitResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
inherited
-
createState(
) → State< NitrogenInitApp> - Creates the mutable state for this component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited