isWindowsCppModule function

bool isWindowsCppModule(
  1. File specFile
)

Returns true when the spec file uses direct C++ for Windows only. Windows C++ modules use windows/CMakeLists.txt (not the shared src/) and need their own impl stub created in windows/src/.

Implementation

bool isWindowsCppModule(File specFile) =>
    PlatformTargetAnalyzer.fromSpec(specFile).supportsWindows;