commands/migrate_command library
CocoaPods to SPM migration command for nitrogen CLI.
Provides automatic detection of legacy CocoaPods setup and migration to Swift Package Manager with backup support.
CocoaPods to SPM migration command for nitrogen CLI.
Provides automatic detection of legacy CocoaPods setup and migration to Swift Package Manager with backup support.