MigrateView class

Constructors

MigrateView({required String pluginName, required MigrationResult result, required SpmStatus spmStatus, bool createBackup = true, VoidCallback? onExit, Key? key})
const

Properties

createBackup bool
final
hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
onExit → VoidCallback?
final
pluginName String
final
result MigrationResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spmStatus SpmStatus
final

Methods

createElement() → StatefulElement
inherited
createState() → State<MigrateView>
Creates the mutable state for this component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited