PackageSwiftValidation class

Validation result for a Package.swift file.

Constructors

PackageSwiftValidation({List<String> issues = const [], List<String> warnings = const [], bool hasSwiftTarget = false, bool hasCppTarget = false, bool hasCorrectPlatform = false, bool hasNitroFlags = false})

Properties

hasCorrectPlatform bool
final
hasCppTarget bool
final
hashCode int
The hash code for this object.
no setterinherited
hasNitroFlags bool
final
hasSwiftTarget bool
final
issues List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited