SpmSourcesValidation class

Verifies SPM Sources directory structure is correct.

Constructors

SpmSourcesValidation({required bool isValid, List<String> missingDirs = const [], List<String> missingSymlinks = const [], List<String> issues = const []})

Properties

hashCode int
The hash code for this object.
no setterinherited
issues List<String>
final
isValid bool
final
missingDirs List<String>
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited