NativeSpecChangeDebouncer class

Constructors

NativeSpecChangeDebouncer({required Duration delay, required FutureOr<void> onReady(List<String> paths), void onError(Object error, StackTrace stackTrace)?})

Properties

delay Duration
final
hashCode int
The hash code for this object.
no setterinherited
onError → void Function(Object error, StackTrace stackTrace)?
final
onReady FutureOr<void> Function(List<String> paths)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
schedule(String path) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited