HoverButton class

Constructors

HoverButton({required String label, required VoidCallback onTap, Color color = Colors.cyan})
const

Properties

color → Color
final
hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
label String
final
onTap → VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
inherited
createState() → State<HoverButton>
Creates the mutable state for this component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited