Centralized build/toolchain versions used by generated Nitro plugin files.
Keep these constants as the single source of truth for scaffold, link, doctor, and migration helpers so generated platform files do not drift.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- androidCompileSdk → const String
- androidJavaVersion → const String
- androidJvmTarget → const String
- androidMinSdk → const String
- androidNdk → const String
- cmakeCxxStandard → const String
- cmakeMinimum → const String
- iosDeployment → const String
- iosPlatformSpec → const String
- kotlinCoroutines → const String
- macosDeployment → const String
- macosPlatformSpec → const String
- podCxxStandard → const String
- podSwiftVersion → const String
- spmCxxFlag → const String
- swiftTools → const String