attach method
Attach this render object to the tree with the given owner.
Implementation
@override
void attach(PipelineOwner owner) {
super.attach(owner);
_child?.attach(owner);
}
Attach this render object to the tree with the given owner.
@override
void attach(PipelineOwner owner) {
super.attach(owner);
_child?.attach(owner);
}