depth property
Get the depth of this node in the tree (for sorting)
Implementation
int get depth {
int count = 0;
RenderObject? node = parent;
while (node != null) {
count++;
node = node.parent;
}
return count;
}
Get the depth of this node in the tree (for sorting)
int get depth {
int count = 0;
RenderObject? node = parent;
while (node != null) {
count++;
node = node.parent;
}
return count;
}