hitTestChildren method
Override this to test whether your children hit at the given position.
Implementation
bool hitTestChildren(HitTestResult result, {required Offset position}) {
return false;
}
Override this to test whether your children hit at the given position.
bool hitTestChildren(HitTestResult result, {required Offset position}) {
return false;
}