hitTestSelf method
Override this to test whether this render object hits at the given position.
Implementation
@protected
bool hitTestSelf(Offset position) => false;
Override this to test whether this render object hits at the given position.
@protected
bool hitTestSelf(Offset position) => false;