markNeedsLayout method

void markNeedsLayout()
inherited

Mark this render object as needing layout.

This will cause performLayout to be called during the next layout pass. The layout mark is propagated up the tree to ensure ancestors also re-layout.

Implementation

void markNeedsLayout() {
  // Always set the flag and call markNeedsPaint() to ensure requestVisualUpdate()
  // is called, even if the flag was already set. This prevents rendering from
  // permanently stopping when the frame-skip optimization is active.
  _needsLayout = true;
  markNeedsPaint();
  parent?.markNeedsLayout();
}