parent property
RenderObject?
parent
getter/setter pairinherited
The parent of this render object in the render tree.
Implementation
RenderObject? parent;
The parent of this render object in the render tree.
RenderObject? parent;