selectionId property
Stable identity used by features that need to track render objects across rebuilds (e.g., selection). Defaults to the render object instance.
Implementation
Object? selectionId;
Stable identity used by features that need to track render objects across rebuilds (e.g., selection). Defaults to the render object instance.
Object? selectionId;