ProcessView class

Constructors

ProcessView({required String title, required String executable, required List<String> args, String? workingDirectory, Key? key})
const

Properties

args List<String>
final
executable String
final
hashCode int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
workingDirectory String?
final

Methods

createElement() → StatefulElement
inherited
createState() → State<ProcessView>
Creates the mutable state for this component.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited