ModuleInfo class
Module descriptor.
isCpp— at least one platform uses direct C++ (broad; used for System.loadLibrary, Swift-bridge skipping, stub file creation).isNativeCpp— android or linux uses direct C++ (narrow; used for src/CMakeLists.txt HybridXxx.cpp inclusion).iosIsCpp/macosIsCpp— per-Apple-platform C++ flags (used for per-platform forwarder decisions and auto-register platform guards).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iosIsCpp → bool
-
final
- isAndroidCpp → bool
-
True only when
android: NativeImpl.cpp— distinct from isNativeCpp which is true for android OR linux. Used to generate the correct auto-register platform guard: Linux-only C++ must exclude ANDROID.final - isCpp → bool
-
final
- isNativeCpp → bool
-
final
- lib → String
-
final
- macosIsCpp → bool
-
final
- module → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, String> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited