ModuleInfo class

Module descriptor.

  • isCpp — at least one platform uses direct C++ (broad; used for System.loadLibrary, Swift-bridge skipping, stub file creation).
  • isNativeCpp — android or linux uses direct C++ (narrow; used for src/CMakeLists.txt HybridXxx.cpp inclusion).

Constructors

ModuleInfo({required String lib, required String module, required bool isCpp, bool isNativeCpp = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isCpp bool
final
isNativeCpp bool
final
lib String
final
module String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited