SpmStatus class
Result of SPM detection for a plugin.
Constructors
Properties
- hasCocoaPods → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSpm → bool
-
final
- iosHasPodspec → bool
-
final
- iosHasSpm → bool
-
final
- iosPackageSwiftPath → String?
-
final
- isLegacy → bool
-
no setter
- isMixed → bool
-
no setter
- isModern → bool
-
no setter
-
issues
→ List<
String> -
final
- macosHasPodspec → bool
-
final
- macosHasSpm → bool
-
final
- macosPackageSwiftPath → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
warnings
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited