NitroCommand enum
Values
- init → const NitroCommand
-
const NitroCommand('Initialize', 'Scaffold a new Nitro FFI plugin project.', '/init', 'Creates all necessary boilerplate for your C++/Kotlin/Swift bridges.'… - generate → const NitroCommand
-
const NitroCommand('Generate', 'Run the Nitro code generator (build_runner).', '/generate', 'Parses your Dart interfaces and generates the native marshalling code.'… - watch → const NitroCommand
-
const NitroCommand('Watch', 'Run the Nitro generator in watch mode.', '/watch', 'Automatically regenerates bridges whenever you save your Dart files.') - link → const NitroCommand
-
const NitroCommand('Link', 'Wire native bridges into the build system.', '/link', 'Automatically configures CMake, Gradle, and CocoaPods for your bridges.') - doctor → const NitroCommand
-
const NitroCommand('Doctor', 'Check if the plugin is production-ready.', '/doctor', 'Validates your project structure, native dependencies, and environment.') - update → const NitroCommand
-
const NitroCommand('Update', 'Self-update the Nitrogen CLI.', '/update', 'Fetches the latest version of nitrogen from pub.dev.') - openCode → const NitroCommand
-
const NitroCommand('Open in VS Code', 'Open project in VS Code.', '/', 'Launches standard VS Code for development.') - openAntigravity → const NitroCommand
-
const NitroCommand('Open in Antigravity', 'Open project in Antigravity.', '/', 'Launches the Antigravity editor for AI-first development.') - exit → const NitroCommand
-
const NitroCommand('Exit', 'Close the Nitrogen CLI.', '/exit', 'Quits the interactive dashboard session.')
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
final
- longInfo → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NitroCommand> - A constant List of the values in this enum, in order of their declaration.