iosPodTargetXcconfig top-level constant
String
const iosPodTargetXcconfig
The pod_target_xcconfig block for iOS podspecs.
Sets the header search paths so the generated C++ bridge headers are visible to both Swift and Obj-C++ source files during pod compilation.
Implementation
const String iosPodTargetXcconfig = r"""s.pod_target_xcconfig = {
'DEFINES_MODULE' => 'YES',
'CLANG_CXX_LANGUAGE_STANDARD' => 'c++17',
'CLANG_CXX_LIBRARY' => 'libc++',
'HEADER_SEARCH_PATHS' => '$(inherited) "${PODS_ROOT}/../.symlinks/plugins/nitro/src/native" "${PODS_TARGET_SRCROOT}/../src" "${PODS_TARGET_SRCROOT}/../lib/src/generated/cpp"'
}""";