markNeedsPaint method
void
markNeedsPaint()
inherited
Mark this render object as needing to be repainted.
This will cause paint to be called during the next paint pass.
The paint request will propagate up to the root, which will trigger
a frame to be scheduled.
Implementation
void markNeedsPaint() {
// Always set the flag (don't early return if already dirty)
// We still need to propagate to ensure requestVisualUpdate() is called
_needsPaint = true;
if (parent != null) {
// Continue propagation up the tree
parent!.markNeedsPaint();
} else {
// We're the root - always request visual update to ensure a frame
// gets scheduled, even if the flag was already set
owner?.requestVisualUpdate();
}
}