setupParentData method
void
setupParentData(
- covariant RenderObject child
inherited
Setup parent data for a child render object.
This is called when a child is added to ensure it has the correct parent data type for this parent.
Implementation
void setupParentData(covariant RenderObject child) {
// Default implementation does nothing
// Subclasses should override to initialize parentData
}