size property
Size
get
size
inherited
The size of this render object as determined during layout.
This value is set by performLayout and should not be set directly
except within performLayout.
Implementation
Size get size => _size!;
- @protected
inherited
Protected setter for size that should only be used in performLayout.
Implementation
@protected
set size(Size value) {
_size = value;
}